@@ -2,7 +2,7 @@ package Net::GitHub::V2::Issues;
 
 use Any::Moose;
 
-our $VERSION = '0.18';
+our $VERSION = '0.28';
 our $AUTHORITY = 'cpan:FAYLAND';
 
 with 'Net::GitHub::V2::HasRepo';
@@ -115,43 +115,11 @@ sub comments {
     my ( $self, $id ) = @_;
     my $owner   = $self->owner;
     my $repo    = $self->repo;
-    my $content = $self->get("http://github.com/$owner/$repo/issues#issue/$id");
-    require HTML::TreeBuilder;
-    my $tree = HTML::TreeBuilder->new;
-    $tree->parse_content($content);
-    $tree->elementify;
-    $tree = $tree->look_down( id => "issue_$id" );
-    return [] unless $tree;
-    my $comments_region = $tree->look_down( class => "comments commentstyle" );
-    if ($comments_region) {
-        my @comments_tree =
-          $comments_region->look_down( class => 'comment wikistyle' );
-        my @comments;
-        for my $c (@comments_tree) {
-            my ($id) = $c->attr('id') =~ /comment_(\d+)/;
-            my $meta    = $c->look_down( class => 'meta' );
-            my $author  = $meta->find_by_tag_name('b')->as_text;
-            my $date =
-              $meta->look_down( class => 'date' )
-              ->look_down( class => 'relatize' )->attr('title');
-            # hack $date to make it consistent with official api
-            $date =~ s!-!/!g;
-            $date .= ' -0700';
 
-            my $content = $c->look_down( class => 'body' )->as_text;
-            push @comments,
-              {
-                id      => $id,
-                author  => $author,
-                date    => $date,
-                content => $content,
-              };
-        }
-        return \@comments;
-    }
-    else {
-        return [];
-    }
+    my $url = "issues/comments/$owner/$repo/$id";
+    my $result = $self->get_json_to_obj( $url, 'comments');
+
+    return $result;
 }
 
 no Any::Moose;
@@ -257,18 +225,17 @@ comment on issues
 
 =item comments
 
-note: this is not the official api of github, in fact,
-      it's done by scrapping.
-
     my $comments = $issue->comments( $number );
 
 return an arrayref containing a list of comments, each comment is a hashref like
 
     {
-        id      => 12345,
-        author  => 'foo',
-        date    => '2009/06/08 18:28:42 -0700',
-        content => 'blalba',
+        id           => 12345,
+        gravatar_id  => 12345,
+        user         => 'foo',
+        created_at   => '2009/06/08 18:28:42 -0700',
+        modified_at  => '2009/06/08 18:28:42 -0700',
+        body         => 'blalba',
     }
 
 if no comments, return []
